## START: Set by rpmautospec
## (rpmautospec version 0.2.5)
%define autorelease(e:s:pb:) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{?dist}
## END: Set by rpmautospec

%global srcname dask

# Requires distributed, which is a loop.
# Also, some tests require packages that require dask itself.
# Force bootstrap for package review.
%bcond_without bootstrap

Name:           python-%{srcname}
Version:        2022.2.1
%global tag     2022.02.1
%global commit  217561b4266c170f452471fed64123940066c4b8
Release:        %autorelease
Summary:        Parallel PyData with Task Scheduling

License:        BSD
URL:            https://github.com/dask/dask/
Source0:        https://github.com/dask/dask/archive/%{tag}/%{srcname}-%{tag}.tar.gz
# Grab this from the sdist until we switch back to it.
Source1:        _version.py
# https://github.com/dask/dask/issues/6725
Patch0001:      0001-Skip-test_encoding_gh601-on-big-endian-machines.patch

BuildArch:      noarch

%description
Dask is a flexible parallel computing library for analytics.


%package -n     python3-%{srcname}
Summary:        %{summary}

BuildRequires:  python3-devel
BuildRequires:  python3dist(graphviz)
BuildRequires:  python3dist(ipython)
%if %{without bootstrap}
BuildRequires:  python3dist(scikit-image)
BuildRequires:  python3dist(xarray)
%endif
# Optional test requirements.
BuildRequires:  python3dist(fastavro)
BuildRequires:  python3dist(h5py)
BuildRequires:  python3dist(psutil)
BuildRequires:  python3dist(requests)
BuildRequires:  python3dist(sqlalchemy)
BuildRequires:  python3dist(zarr)

Recommends:     python3-%{srcname}+array = %{version}-%{release}
Recommends:     python3-%{srcname}+bag = %{version}-%{release}
Recommends:     python3-%{srcname}+dataframe = %{version}-%{release}
Recommends:     python3-%{srcname}+delayed = %{version}-%{release}
Recommends:     python3-%{srcname}+diagnostics = %{version}-%{release}
%if %{without bootstrap}
Recommends:     python3-%{srcname}+distributed = %{version}-%{release}
%endif

%description -n python3-%{srcname}
Dask is a flexible parallel computing library for analytics.


%pyproject_extras_subpkg -n python3-%{srcname} array bag dataframe delayed diagnostics
%if %{without bootstrap}
%pyproject_extras_subpkg distributed
%endif


%if %{without bootstrap}
%package -n python-%{srcname}-doc
Summary:        dask documentation

BuildRequires:  python3dist(dask_sphinx_theme) >= 1.3.5
BuildRequires:  python3dist(numpydoc)
BuildRequires:  python3dist(sphinx) >= 4

%description -n python-%{srcname}-doc
Documentation for dask.
%endif


%prep
%autosetup -n %{srcname}-%{tag} -p1
sed -e 's/@version@/%{tag}/' -e 's/@commit@/%{commit}/' %SOURCE1 > %{srcname}/_version.py


%generate_buildrequires
%pyproject_buildrequires -r -x test,array,bag,dataframe,delayed,diagnostics
%if %{without bootstrap}
%pyproject_buildrequires -x distributed
%endif


%build
%pyproject_wheel

%if %{without bootstrap}
# generate html docs
PYTHONPATH=${PWD} sphinx-build-3 docs/source html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif


%install
%pyproject_install

%pyproject_save_files %{srcname}


%check
%ifarch arm
# Is there a way to do this in one line?
%global have_arm 1
%endif

pytest_args=(
  -m 'not network'

  # https://bugzilla.redhat.com/show_bug.cgi?id=1968947#c4
  --deselect=dask/dataframe/io/tests/test_sql.py::test_select_from_select

  -n %[0%{?have_arm}?"2":"auto"]

  # Ignore https://github.com/numpy/numpy/issues/20225 and Pandas issues
  -W ignore::DeprecationWarning
)

%{pytest} "${pytest_args[@]}"

%files -n python3-%{srcname} -f %{pyproject_files}
%doc README.rst
%license LICENSE.txt

%if %{without bootstrap}
%files -n python-%{srcname}-doc
%doc html
%license LICENSE.txt
%endif


%changelog
* Sun Mar 06 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2022.2.1-2
- Fix provided version in metadata

* Sun Feb 27 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2022.2.1-1
- Update to latest version (#2058755)

* Sat Feb 12 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2022.2.0-1
- Update to latest version (#2053679)

* Sat Jan 29 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2022.1.1-1
- Update to latest version (#2047914)

* Sun Jan 16 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2022.1.0-3
- Fix version in metadata

* Sun Jan 16 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2022.1.0-1
- Update to latest version (#2040923)

* Mon Dec 20 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2021.12.0-1
- Update to latest version (#2016711)

* Wed Sep 22 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2021.9.1-1
- Update to latest version (#2006577)

* Sat Sep 04 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2021.9.0-1
- Update to latest version (#2001121)

* Sat Aug 21 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2021.8.1-1
- Update to latest version (#1993560)

* Sat Aug 21 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2021.8.0-3
- Add missing diagnostics subpackage.

* Sat Aug 21 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2021.8.0-2
- Switch to latest Python macros.

* Sat Aug 14 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2021.8.0-1
- Update to latest version (#1993560)

* Sat Jul 31 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> 2021.7.2-1
- Update to latest version (#1985515)

* Mon Jul 26 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.7.1-1
- Update to latest version (#1985515)

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2021.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sun Jul 11 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.7.0-1
- Update to latest version (#1980906)

* Sun Jul 04 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.6.2-1
- Update to latest version (#1974872)

* Sat Jun 19 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.6.1-1
- Update to latest version (#1973783)

* Thu Jun 17 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2021.6.0-1
- Skip some failing tests for now

* Sun Jun 13 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2021.6.0-1
- Update to latest version (#1965698)

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 2021.5.0-2
- Rebuilt for Python 3.10

* Sat May 15 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.5.0-1
- Update to latest version (#1960766)

* Sat Apr 24 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.4.1-1
- Update to latest version (#1953086)

* Fri Apr 02 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.4.0-1
- Update to latest version (#1943694)

* Sun Mar 07 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.3.0-1
- Update to latest version (#1936017)

* Fri Feb 05 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.2.0-1
- Update to latest version (#1925645)

* Wed Jan 27 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.1.1-1
- Update to latest version (#1919397)

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2021.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jan 19 2021 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2021.1.0-1
- Update to latest version (#1906637)

* Sat Oct 10 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.30.0-1
- Update to latest version (#1884852)

* Mon Oct 05 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.29.0-1
- Update to latest version (#1884852)

* Sat Sep 26 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.28.0-1
- Update to latest version (#1882873)

* Fri Sep 18 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.27.0-1
- Update to latest version (#1880693)

* Sat Sep 12 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.26.0-1
- Update to latest version (#1878309)

* Fri Aug 28 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.25.0-1
- Update to latest version (#1873659)

* Sun Aug 23 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.24.0-1
- Update to latest version (#1871358)

* Sat Aug 15 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.23.0-1
- Update to latest version (#1868951)

* Sun Aug 02 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.22.0-1
- Update to latest version

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.21.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jul 18 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.21.0-1
- Update to latest version

* Fri Jul 10 2020 Miro Hrončok <mhroncok@redhat.com> - 2.20.0-2
- Add metadata for Python extras subpackages

* Sun Jul 05 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.20.0-1
- Update to latest version

* Sat Jun 06 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.18.0-1
- Update to latest version

* Sun May 31 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.17.2-1
- Update to latest version

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 2.16.0-2
- Rebuilt for Python 3.9

* Sat May 09 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.16.0-1
- Update to latest version

* Wed Apr 08 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.14.0-1
- Update to latest version

* Thu Mar 26 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.13.0-1
- Update to latest version

* Sat Mar 07 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.12.0-1
- Update to latest version

* Fri Feb 21 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.11.0-3
- Fix typo in dependency
- Fix flaky test

* Wed Feb 19 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.11.0-2
- Fix minimum dependency versions
- Make keeping minimum dependency versions in sync a bit easier

* Wed Feb 19 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.11.0-1
- Update to latest version

* Fri Feb 14 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.10.1-1
- Update to latest version

* Tue Jan 28 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.10.0-1
- Update to latest version

* Thu Jan 09 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.9.1-1
- Update to latest version

* Fri Nov 22 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.8.1-1
- Update to latest version

* Thu Nov 21 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.8.0-1
- Update to latest version

* Tue Nov 12 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.7.0-1
- Update to latest version
- Disabled distributed subpackage until it's available

* Thu Oct 17 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.6.0-1
- Update to latest version

* Sat Oct 05 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.5.2-1
- Update to latest version

* Sat Sep 28 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.5.0-1
- Update to latest version

* Fri Sep 13 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.4.0-1
- Update to latest version

* Thu Sep 12 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.3.0-1
- Update to latest version

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 2.1.0-3
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Jul 23 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.1.0-1
- Update to latest version

* Sat Apr 13 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.2.0-1
- Update to latest version

* Mon Apr 01 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.1.5-1
- Update to latest version

* Sat Mar 09 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.1.4-1
- Update to latest version
- Remove now unnecessary patches

* Wed Mar 06 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.1.3-3
- Mark partitioning test as expected failure on 32-bit systems as well

* Wed Mar 06 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.1.3-2
- Add meta-subpackages for individual features

* Sat Mar 02 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.1.3-1
- Initial package.

